@@ -4,8 +4,9 @@ use warnings;
 use File::Temp qw(tempfile);
 
 sub new {
-    my ($fh, $filename) = tempfile();
-    return bless({ tempfile => $fh, filename => $filename }, shift) }
+    my ( $fh, $filename ) = tempfile();
+    return bless( { tempfile => $fh, filename => $filename }, shift );
+}
 
 sub run {
     my $self = shift;
